@@ -350,7 +350,8 @@ def from_numpy(histogram):
     valuesarray[-1] = 0
 
     out.extend(valuesarray)
-    out._fSumw2 = valuesarray ** 2
+    # variances equal the entries
+    out._fSumw2 = valuesarray
 
     return out
 
